summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/codegenerator.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/codegenerator.h')
-rw-r--r--umbrello/umbrello/codegenerator.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/umbrello/umbrello/codegenerator.h b/umbrello/umbrello/codegenerator.h
index d47fd73f..eedec15d 100644
--- a/umbrello/umbrello/codegenerator.h
+++ b/umbrello/umbrello/codegenerator.h
@@ -81,6 +81,7 @@ class KConfig;
class CodeGenerator : public TQObject {
Q_OBJECT
+ TQ_OBJECT
public:
@@ -200,7 +201,7 @@ public:
* %time%
* %filepath%
*
- * @return QString
+ * @return TQString
* @param file
*/
virtual TQString getHeadingFile (const TQString &file );
@@ -218,7 +219,7 @@ public:
/**
* Replaces spaces with underscores and capitalises as defined in m_modname
- * @return QString
+ * @return TQString
* @param name
*/
static TQString cleanName ( const TQString &name );
@@ -280,7 +281,7 @@ public:
/** Get the editing dialog for this code document
*/
- virtual CodeViewerDialog * getCodeViewerDialog( TQWidget* parent, CodeDocument * doc,
+ virtual CodeViewerDialog * getCodeViewerDialog( TQWidget* tqparent, CodeDocument * doc,
Settings::CodeViewerState state);
/**
@@ -303,7 +304,7 @@ public:
virtual void createDefaultStereotypes ();
/**
* Initialize this code generator from its parent UMLDoc. When this is called,
* it will (re-)generate the list of code documents for this project (generator)
* by checking for new objects/attributes which have been added or changed in the
* document. One or more CodeDocuments will be created/overwritten/amended as is
@@ -339,7 +340,7 @@ protected:
* @param name the proposed output file name
* @param extension the extension to use
* @return the real file name that should be used (including extension) or
- * TQString::null if none to be used
+ * TQString() if none to be used
*/
TQString overwritableName (const TQString& name, const TQString &extension );
@@ -393,7 +394,7 @@ public slots:
virtual void checkRemoveUMLObject (UMLObject * obj);
/**
* Force a synchronize of this code generator, and its present contents, to that of the parent UMLDocument.
* "UserGenerated" code will be preserved, but Autogenerated contents will be updated/replaced
* or removed as is apppropriate.
*/
@@ -303,7 +304,7 @@ public:
virtual void createDefaultStereotypes ();
/**
- * Initialize this code generator from its parent UMLDoc. When this is called,
+ * Initialize this code generator from its tqparent UMLDoc. When this is called,
* it will (re-)generate the list of code documents for this project (generator)
* by checking for new objects/attributes which have been added or changed in the
@@ -393,7 +394,7 @@ public slots:
virtual void checkRemoveUMLObject (UMLObject * obj);
/**
- * Force a synchronize of this code generator, and its present contents, to that of the parent UMLDocument.
+ * Force a synchronize of this code generator, and its present contents, to that of the tqparent UMLDocument.
* "UserGenerated" code will be preserved, but Autogenerated contents will be updated/replaced
* or removed as is apppropriate.